from setuptools import setup, find_packages
import sys

if sys.version_info[0] < 3:
    with open('README.md') as f:
        README = f.read()
else:
    with open('README.md', encoding='utf-8') as f:
        README = f.read()

setup(
    name="conventional-commits-check",
    version="1.0.2",
    description="A pre-commit hook to check Conventional Commits and add emojis.",
    author="Ali Yaman",
    packages=find_packages(),
    license="MIT",
    long_description_content_type="text/markdown",
    long_description=README,
    url="https://github.com/AliYmn/conventional-commits-check",
    install_requires=["pre-commit"],
    entry_points={"console_scripts": [
        "conventional-commits-check = conventional_commits_check.main:main"]},
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.0',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
    ],
)



#!/usr/bin/env python3
import argparse
import re
import sys
from typing import Dict
import yaml

COMMIT_TYPES = {
    "feat": "^feat(\(.+\))?:",
    "fix": "^fix(\(.+\))?:",
    "docs": "^docs(\(.+\))?:",
    "style": "^style(\(.+\))?:",
    "refactor": "^refactor(\(.+\))?:",
    "perf": "^perf(\(.+\))?:",
    "test": "^test(\(.+\))?:",
    "build": "^build(\(.+\))?:",
    "ci": "^ci(\(.+\))?:",
    "chore": "^chore(\(.+\))?:",
    "revert": "^revert: ",
}

EMOJIS = {
    "feat": "✨",
    "fix": "🐛",
    "docs": "📚",
    "style": "💎",
    "refactor": "🧹",
    "perf": "🚀",
    "test": "🧪",
    "build": "🏗️",
    "ci": "👷",
    "chore": "♻️",
    "revert": "⏪",
}


def load_custom_rules(config_file="conventional_commits_check_config.yaml"):
    try:
        with open(config_file, "r") as file:
            config_data = yaml.safe_load(file)

        return config_data.get("additional_commands", {}), config_data.get("additional_emojis", {})

    except FileNotFoundError:
        pass

    return {}, {}


def main():
    additional_commands, additional_emojis = load_custom_rules()

    # Merge additional commands and emojis with the existing ones
    COMMIT_TYPES.update(additional_commands)
    EMOJIS.update(additional_emojis)

    parser = argparse.ArgumentParser()
    parser.add_argument("commit_message_file")
    args = parser.parse_args()

    with open(args.commit_message_file, "r") as file:
        commit_message = file.read()

    commit_type = None
    for commit, pattern in COMMIT_TYPES.items():
        if re.match(pattern, commit_message.strip()):
            commit_type = commit
            break

    if not commit_type:
        print("Commit message does not follow Conventional Commits rules.")
        sys.exit(1)

    emoji = EMOJIS.get(commit_type)

    if emoji:
        new_commit_message = f"{emoji} {commit_message}"
        with open(args.commit_message_file, "w") as file:
            file.write(new_commit_message)

    print("Commit message follows Conventional Commits rules and has been updated with an emoji.")
    sys.exit(0)


if __name__ == "__main__":
    main()
